==> dl.php?src=linea21_1_6.zip: linea21/languages/it/lang_yellowpages.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage it
 * @author Alessandra Rossi & linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['yp']['section'] = "Rubrica delle organizzazioni";


/*	nommage des modules
 *  	*/
$lang['yp']['name']="organizzazione";
$lang['yp']['confirm_add'] = "Aggiunta dell'organizzazione avvenuta con successo\n";
$lang['yp']['confirm_mod'] = "Modifica dell'organizzazione avvenuta con succeso\n";
$lang['yp']['confirm_sup'] ="Eliminazione dell'organizzazione avvenuta con successo\n";
$lang['yp']['confirm_pub']= "La tua organizzazione è stata aggiunta con successo, la tua iscrizione sarà convalidata dall'amministratore";
$lang['yp']['confirm_pub2']= "clicca qui per ritornare alla rubrica";
/*	nommage rubrique module
 *  	*/
$lang['yp']['add']= "Aggiunta di una ".$lang['yp']['name'];
$lang['yp']['mod']= "Modifica di una ".$lang['yp']['name'];
$lang['yp']['sup']= "Eliminazione di una ".$lang['yp']['name'];
$lang['yp']['det']= "Dettagli della".$lang['yp']['name'];
$lang['yp']['list']= "Consultazione della rubrica ";
$lang['yp']['nb_total']='organizzazioni iscritte';

/*	publique
 *  	*/
$lang['yp']['add_public']= "Aggiungi la tua ".$lang['yp']['name'];
$lang['yp']['h1_public_comment']='Troverai nella rubrica l\'insieme delle organizzazioni legate ai problemi di sviluppo sostenibile e al '.SITE_NAME.'. Se vuoi comparire nella rubrica, aggiungi le tue coordinate cliccando su "aggiunta dell tua organizzazione".';
$lang['yp']['h1_public_add']='L\'aggiunta della tua organizzazione nella nostra rubrica è gratuita, riempi il modulo qui sotto, una email del nostro amministratore ti confermerà le tue referenze nella nostra rubrica quando sarà effettiva.';


/*	nommage rubrique add / mod /det
 *  	*/
$lang['yp']['add_title']="Inserimento delle informazioni della nuova ".$lang['yp']['name'];
$lang['yp']['mod_title']="Modifica delle informazioni della".$lang['yp']['name'];
$lang['yp']['recap_commment']="nessun commento";
$lang['yp']['confirmation']="confermare l'iscrizione";
$lang['yp']['actions']='azioni';


/*	nommage email
 *  	*/


$lang['yp']['mail_entete']="la tua iscrizione su ".SITE_NAME." è stata presa in carico, qui allegate troverai le informazione della tua organizzazione che appariranno nella nostra rubrica";
$lang['yp']['mail_body1']="Vieni a trovarci su";
$lang['yp']['mail_bottom']="Per qualsiasi domanda reativa al tuo accesso";
$lang['yp']['confirm_subscription']='conferma della tua iscrizione su';

/*	nommage rubrique sup
 *  	*/
$lang['yp']['sup_yp_warning']="Sei sicuro di voler eliminare definitivamente questa ".$lang['yp']['name']." ?";


/*	nommage élément rubrique
 *  	*/

$lang['yp']['name2']="nome dell'organizzazione";
$lang['yp']['activity']="ambito(i) d'attività";
$lang['yp']['street']="via";
$lang['yp']['postal_code']="codice postale";
$lang['yp']['infos_adresse']="indirizzo e informazioni complementari";
$lang['yp']['adresse']="indirizzo";
$lang['yp']['city']="città";
$lang['yp']['country']="paese";
$lang['yp']['phone']="telefono";
$lang['yp']['fax']="fax";
$lang['yp']['email']="email";
$lang['yp']['website']="sito internet";
$lang['yp']['theme']="temi di collegamento";


/*	nommage quickbox
 *  	*/
$lang['yp']['qb_title']=" ultime modifiche effettuate";


/*	divers
 *  	*/
$lang['yp']['select_choice']="-- Scegli nella lista qui sotto --";
$lang['yp']['facultatif']="facoltativo";
$lang['yp']['theme_filter']="Visualizza per tema";
$lang['yp']['notheme']="nessun tema selezionato";
$lang['yp']['title_theme']="Organizzazioni aventi per tema";
$lang['yp']['title_statut']="Organizzazioni aventi per status";
$lang['yp']['statut_filter']="Visualizza per status";
$lang['yp']['preinscription']="Visualizza le preiscirzioni";
$lang['yp']['all']="Visualizza la rubrica completa";
$lang['yp']['draft']="in pre-iscrizione";
$lang['yp']['noresult']="nessuna organizzazione corrisponde a questo criterio di selezione.";
$lang['yp']['alphabetical']=' [A-Z] ';


/*	messages
 *  	*/


$lang['yp']['object_notname']="Devi tassativamente inserire un nome ddi organizzazione.";
$lang['yp']['object_notactivity']="Devi tassativamente inserire un ambito di attività per questa organizzazione.";
$lang['yp']['object_notstreet']="Devi tassativamente inserire una via per l'indirizzo di questa organizzazione.";
$lang['yp']['object_notpostal_code']="Devi tassativamente inserire un codice postale per l'indirizzo di questa organizzazione.";
$lang['yp']['object_notcity']="Devi tassativamente inserire una città per l'indirizzo di questa organizzazione.";
$lang['yp']['object_notcountry']="Devi tassativamente inserire un paese per l'indirizzo di questa organizzazione.";
$lang['yp']['object_notemail']="l'email inserita non è valida.";
$lang['yp']['object_notphone']="il numero di telefono inserito non è valido.";
$lang['yp']['object_notfax']="il numero di fax inserito non è valido.";
$lang['yp']['invalid_protocol']='Il protocollo indicato non è stato riconosciuto dall\'applicazione. Per favore, verifica la sintassi.';


/*	rubrique d'aide
 *  	*/
$lang['yp']['help_add1']="Per aggiungere un'organizzazione, devi inserire ciascuno di questi parametri nel modulo qui sotto";
$lang['yp']['help_add2']="Dopo aver convalidato il modulo d'aggiunta, controlla i parametri d'aggiunta nel riepilogo";
$lang['yp']['help_add3']="Se il riepilogo non ti soddisfa, puoi cliccare su \"modifica i parametri\" per modificarli";


$lang['yp']['help_list1']="Per visualizzare un'organizzazione nel dettaglio, clicca sul nome della medesima";
$lang['yp']['help_list2']="Puoi eliminare un'organizzazione cliccando sull'icona di eliminazione ad essa associata";
$lang['yp']['help_list3']="Puoi modificare un'organizzazione cliccando sull'icona di modifica ad essa associata";
$lang['yp']['help_list4']="Per aggiungere un'organizzazione, clicca sul link \"aggiungere un'orgnizzazione\" nella barra degli strumenti";
$lang['yp']['help_list5']="Puoi effettuare una ricerca nella rubrica in ogni momento cliccando su \"ricerca\"";
$lang['yp']['help_list6']="Puoi visualizzare le organizzazioni in pre-iscrizione selezionando \"visualizza le pre-iscrizioni\"";
$lang['yp']['help_list7']="Per convalidare una pre-iscrizione, clicca sul pulsante corrispondente nella pagina \"dettagli di un'organizzazione\"";
//$lang['yp']['help_list8']="Puoi visualizzare le organizzazioni selezionate per tema in \"visualizza per tema\"";
$lang['yp']['help_list9']="Puoi visualizzare le organizzazioni selezionate per status selezionando uno status";
$lang['yp']['help_list10']="Lo atatus di Amministratore d'Archivio ti permette di conservare l'organizzazione nella rubrica senza viaualizzarla sul sito pubblico.";




$lang['yp']['help_mod1']="Per modificare un'organizzazione, puoi modificare ciascuno di questi parametri nel modulo qui sotto";

$lang['yp']['help_mod2']="Dopo aver convalidato il modulo di modifica, controlla i parametri d'aggiunta nel riepilogo";
$lang['yp']['help_mod3']="Se il riepilogo non ti soddisfa, puoi cliccare su \"modifica i parametri\" per modificarli";
$lang['yp']['help_mod4']="Lo status Amministratore di Archivio ti permette di conservare l'organizzazione nella rubrica senza visualizzarla sul sito pubblico.";




$lang['yp']['help_det1']="Puoi modificare questa organizzazione cliccando sull'icona di modifica ad essa associata";
$lang['yp']['help_det2']="Puoi eliminare questa organizzazione cliccando sull'icona di eliminazione ad essa associata";
$lang['yp']['help_det3']="Per visualizzare il tema dell'organizzazione consultata, clicca sul nome stesso del tema";
$lang['yp']['help_det4']="Se l'organizzazione è in pre-iscrizione, appare il link \"convalidare la pre-iscrizione\", clicca su questo link per convalidare l'iscrizione di questa organizzazione, questa azione invia automaticamente un'email all'organizzazione confermandole l'iscrizione.";


$lang['yp']['help_sup1']="Cliccando su convalidare, l'organizzazione è definitivamente eliminata dalla rubrica.";
$lang['yp']['help_sup2']="L'eliminazione di una pre-iscrizione si effettua anch'essa tramite questa interfaccia.";
?>

==> dl.php?src=linea21_1_7.zip: linea21/languages/it/lang_yellowpages.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage it
 * @author Alessandra Rossi & linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['yp']['section'] = "Rubrica delle organizzazioni";


/*	nommage des modules
 *  	*/
$lang['yp']['name']="organizzazione";
$lang['yp']['confirm_add'] = "Aggiunta dell'organizzazione avvenuta con successo\n";
$lang['yp']['confirm_mod'] = "Modifica dell'organizzazione avvenuta con succeso\n";
$lang['yp']['confirm_sup'] ="Eliminazione dell'organizzazione avvenuta con successo\n";
$lang['yp']['confirm_pub']= "La tua organizzazione è stata aggiunta con successo, la tua iscrizione sarà convalidata dall'amministratore";
$lang['yp']['confirm_pub2']= "clicca qui per ritornare alla rubrica";
/*	nommage rubrique module
 *  	*/
$lang['yp']['add']= "Aggiunta di una ".$lang['yp']['name'];
$lang['yp']['mod']= "Modifica di una ".$lang['yp']['name'];
$lang['yp']['sup']= "Eliminazione di una ".$lang['yp']['name'];
$lang['yp']['det']= "Dettagli della".$lang['yp']['name'];
$lang['yp']['list']= "Consultazione della rubrica ";
$lang['yp']['nb_total']='organizzazioni iscritte';

/*	publique
 *  	*/
$lang['yp']['add_public']= "Aggiungi la tua ".$lang['yp']['name'];
$lang['yp']['h1_public_comment']='Troverai nella rubrica l\'insieme delle organizzazioni legate ai problemi di sviluppo sostenibile e al '.SITE_NAME.'. Se vuoi comparire nella rubrica, aggiungi le tue coordinate cliccando su "aggiunta dell tua organizzazione".';
$lang['yp']['h1_public_add']='L\'aggiunta della tua organizzazione nella nostra rubrica è gratuita, riempi il modulo qui sotto, una email del nostro amministratore ti confermerà le tue referenze nella nostra rubrica quando sarà effettiva.';


/*	nommage rubrique add / mod /det
 *  	*/
$lang['yp']['add_title']="Inserimento delle informazioni della nuova ".$lang['yp']['name'];
$lang['yp']['mod_title']="Modifica delle informazioni della".$lang['yp']['name'];
$lang['yp']['recap_commment']="nessun commento";
$lang['yp']['confirmation']="confermare l'iscrizione";
$lang['yp']['actions']='azioni';


/*	nommage email
 *  	*/


$lang['yp']['mail_body1']="Your registration is now confirmed. You can access the entry by following this link : "; // @todo translation
$lang['yp']['confirm_subscription']='Your organisation is now listed in the directory'; // @todo translation
$lang['yp']['mail_body_added']="Your organisation has been added to the directory."; // @todo translation
$lang['yp']['mail_body_added1']="We added your organisation in our directory.<br /><br />\n\nYou can access it by following the URL : ";  // @todo translation
$lang['yp']['mail_body_added2']="If you want us to remove the entry please contact us.\n"; // @todo translation

/*	nommage rubrique sup
 *  	*/
$lang['yp']['sup_yp_warning']="Sei sicuro di voler eliminare definitivamente questa ".$lang['yp']['name']." ?";


/*	nommage élément rubrique
 *  	*/

$lang['yp']['name2']="nome dell'organizzazione";
$lang['yp']['activity']="ambito(i) d'attività";
$lang['yp']['street']="via";
$lang['yp']['postal_code']="codice postale";
$lang['yp']['infos_adresse']="indirizzo e informazioni complementari";
$lang['yp']['adresse']="indirizzo";
$lang['yp']['city']="città";
$lang['yp']['country']="paese";
$lang['yp']['phone']="telefono";
$lang['yp']['fax']="fax";
$lang['yp']['email']="email";
$lang['yp']['website']="sito internet";
$lang['yp']['theme']="temi di collegamento";


/*	nommage quickbox
 *  	*/
$lang['yp']['qb_title']=" ultime modifiche effettuate";


/*	divers
 *  	*/
$lang['yp']['select_choice']="-- Scegli nella lista qui sotto --";
$lang['yp']['facultatif']="facoltativo";
$lang['yp']['theme_filter']="Visualizza per tema";
$lang['yp']['notheme']="nessun tema selezionato";
$lang['yp']['title_theme']="Organizzazioni aventi per tema";
$lang['yp']['title_statut']="Organizzazioni aventi per status";
$lang['yp']['statut_filter']="Visualizza per status";
$lang['yp']['preinscription']="Visualizza le preiscirzioni";
$lang['yp']['all']="Visualizza la rubrica completa";
$lang['yp']['draft']="in pre-iscrizione";
$lang['yp']['noresult']="nessuna organizzazione corrisponde a questo criterio di selezione.";
$lang['yp']['alphabetical']=' [A-Z] ';


/*	messages
 *  	*/


$lang['yp']['object_notname']="Devi tassativamente inserire un nome ddi organizzazione.";
$lang['yp']['object_notactivity']="Devi tassativamente inserire un ambito di attività per questa organizzazione.";
$lang['yp']['object_notstreet']="Devi tassativamente inserire una via per l'indirizzo di questa organizzazione.";
$lang['yp']['object_notpostal_code']="Devi tassativamente inserire un codice postale per l'indirizzo di questa organizzazione.";
$lang['yp']['object_notcity']="Devi tassativamente inserire una città per l'indirizzo di questa organizzazione.";
$lang['yp']['object_notcountry']="Devi tassativamente inserire un paese per l'indirizzo di questa organizzazione.";
$lang['yp']['object_notemail']="l'email inserita non è valida.";
$lang['yp']['object_notphone']="il numero di telefono inserito non è valido.";
$lang['yp']['object_notfax']="il numero di fax inserito non è valido.";
$lang['yp']['invalid_protocol']='Il protocollo indicato non è stato riconosciuto dall\'applicazione. Per favore, verifica la sintassi.';


/*	rubrique d'aide
 *  	*/
$lang['yp']['help_add1']="Per aggiungere un'organizzazione, devi inserire ciascuno di questi parametri nel modulo qui sotto";
$lang['yp']['help_add2']="Dopo aver convalidato il modulo d'aggiunta, controlla i parametri d'aggiunta nel riepilogo";
$lang['yp']['help_add3']="Se il riepilogo non ti soddisfa, puoi cliccare su \"modifica i parametri\" per modificarli";


$lang['yp']['help_list1']="Per visualizzare un'organizzazione nel dettaglio, clicca sul nome della medesima";
$lang['yp']['help_list2']="Puoi eliminare un'organizzazione cliccando sull'icona di eliminazione ad essa associata";
$lang['yp']['help_list3']="Puoi modificare un'organizzazione cliccando sull'icona di modifica ad essa associata";
$lang['yp']['help_list4']="Per aggiungere un'organizzazione, clicca sul link \"aggiungere un'orgnizzazione\" nella barra degli strumenti";
$lang['yp']['help_list5']="Puoi effettuare una ricerca nella rubrica in ogni momento cliccando su \"ricerca\"";
$lang['yp']['help_list6']="Puoi visualizzare le organizzazioni in pre-iscrizione selezionando \"visualizza le pre-iscrizioni\"";
$lang['yp']['help_list7']="Per convalidare una pre-iscrizione, clicca sul pulsante corrispondente nella pagina \"dettagli di un'organizzazione\"";
//$lang['yp']['help_list8']="Puoi visualizzare le organizzazioni selezionate per tema in \"visualizza per tema\"";
$lang['yp']['help_list9']="Puoi visualizzare le organizzazioni selezionate per status selezionando uno status";
$lang['yp']['help_list10']="Lo atatus di Amministratore d'Archivio ti permette di conservare l'organizzazione nella rubrica senza viaualizzarla sul sito pubblico.";




$lang['yp']['help_mod1']="Per modificare un'organizzazione, puoi modificare ciascuno di questi parametri nel modulo qui sotto";

$lang['yp']['help_mod2']="Dopo aver convalidato il modulo di modifica, controlla i parametri d'aggiunta nel riepilogo";
$lang['yp']['help_mod3']="Se il riepilogo non ti soddisfa, puoi cliccare su \"modifica i parametri\" per modificarli";
$lang['yp']['help_mod4']="Lo status Amministratore di Archivio ti permette di conservare l'organizzazione nella rubrica senza visualizzarla sul sito pubblico.";




$lang['yp']['help_det1']="Puoi modificare questa organizzazione cliccando sull'icona di modifica ad essa associata";
$lang['yp']['help_det2']="Puoi eliminare questa organizzazione cliccando sull'icona di eliminazione ad essa associata";
$lang['yp']['help_det3']="Per visualizzare il tema dell'organizzazione consultata, clicca sul nome stesso del tema";
$lang['yp']['help_det4']="Se l'organizzazione è in pre-iscrizione, appare il link \"convalidare la pre-iscrizione\", clicca su questo link per convalidare l'iscrizione di questa organizzazione, questa azione invia automaticamente un'email all'organizzazione confermandole l'iscrizione.";


$lang['yp']['help_sup1']="Cliccando su convalidare, l'organizzazione è definitivamente eliminata dalla rubrica.";
$lang['yp']['help_sup2']="L'eliminazione di una pre-iscrizione si effettua anch'essa tramite questa interfaccia.";
?>
